.. Seabird documentation master file, created by
   sphinx-quickstart on Sat May 10 08:24:18 2014.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.


:tocdepth: 2

#####################
Seabird Documentation
#####################

.. _user-docs:

******************
User Documentation
******************

**Seabird at a glance**

.. toctree::
   :maxdepth: 1

   overview
   install
   getting_started
   commandline


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

